@@ -31,7 +31,7 @@ impl Dumper for Mysql {
                 "select column_name from information_schema.columns where table_name = '{}' and table_schema = '{}'",
                 options.table, options.database
             ))
-            .expect("Read name row from mysql error");
+            .expect("Query mysql error");
         let name_row: Vec<String> = result_set.into_iter().map(|row| row.0).collect();
         writer.write_row(name_row.clone());
 
@@ -59,7 +59,7 @@ impl Dumper for Mysql {
                     .expect("Send data row to channel error");
             }
             Err(err) => {
-                println!("Read data row from mysql error: {:?}", err);
+                println!("Query mysql error: {:?}", err);
                 exit(1);
             }
         });
